pecos.error\_models.noise\_impl.noise\_sq\_bitflip
==================================================

.. automodule:: pecos.error_models.noise_impl.noise_sq_bitflip







   .. rubric:: Functions

   .. autosummary::

      noise_sq_bitflip
